@@ -1,5 +1,92 @@
 NYSE_HOLIDAYS = [
-{
+    # ---------- 2019 --------------------
+    {
+        'date': '01.01.2019',
+        'name': 'New Year\'s Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '21.01.2019',
+        'name': 'Martin Luther King Jr. Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '18.02.2019',
+        'name': 'Washington\'s Birthday',
+        'status': 'Closed',
+    },
+    {
+        'date': '19.04.2019',
+        'name': 'Good Friday',
+        'status': 'Closed',
+    },
+    {
+        'date': '27.05.2019',
+        'name': 'Memorial Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '04.07.2019',
+        'name': 'Independence Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '02.09.2019',
+        'name': 'Labor Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '28.11.2019',
+        'name': 'Thanksgiving Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '29.11.2019',
+        'name': 'Thanksgiving Day',
+        'status': '9:30 AM - 1:00 PM',
+    },
+    {
+        'date': '24.12.2019',
+        'name': 'Christmas',
+        'status': '9:30 AM - 1:00 PM',
+    },
+    {
+        'date': '25.12.2019',
+        'name': 'Christmas',
+        'status': 'Closed',
+    },
+    # ---------- 2020 --------------------
+    {
+        'date': '01.01.2020',
+        'name': 'New Year\'s Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '20.01.2020',
+        'name': 'Martin Luther King Jr. Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '17.02.2020',
+        'name': 'Washington\'s Birthday',
+        'status': 'Closed',
+    },
+    {
+        'date': '10.04.2020',
+        'name': 'Good Friday',
+        'status': 'Closed',
+    },
+    {
+        'date': '25.05.2020',
+        'name': 'Memorial Day',
+        'status': 'Closed',
+    },
+    {
+        'date': '03.07.2020',
+        'name': 'Independence Day',
+        'status': 'Closed',
+    },
+    {
         'date': '07.09.2020',
         'name': 'Labor Day',
         'status': 'Closed',
